@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: persistent-template
 version: 2.1.5
-id: persistent-template-2.1.5-f7956adf64aebd4eef761b02bf73d3c3
-key: persi_ClRQnjfNF4y8TM3HMasA7c
+id: persistent-template-2.1.5-5a5a189d5669eb41fa0516076c32ca83
+key: persi_3OFXwuDnQRIF9YiSS4BHWE
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -20,24 +20,24 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-template-2.1.5
 library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-template-2.1.5
 data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-template-2.1.5
-hs-libraries: HSpersistent-template-2.1.5-ClRQnjfNF4y8TM3HMasA7c
+hs-libraries: HSpersistent-template-2.1.5-3OFXwuDnQRIF9YiSS4BHWE
 depends:
-    aeson-0.10.0.0-b63a88a6e7bf231c11601ff561c0eb0d
-    aeson-compat-0.3.0.0-3ffd414d5f44f5e3743b6d6d8677523a
+    aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
+    aeson-compat-0.3.0.0-a20a161a51c55c8ab6017f045ab6c3e9
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
-    http-api-data-0.2.2-d3c9f175f1f98718629e761de86ea99f
-    monad-control-1.0.0.4-fa18b603f1c859e06ea8fbebdf00a3e7
-    monad-logger-0.3.17-6bebcabc98fb90582d59aab2ac8cf400
-    path-pieces-0.2.1-1993cf7409b1066d7297872970b0fe71
-    persistent-2.2.4-7522deb7fd39c262180984fc189631e9
-    tagged-0.8.2-849e3b2865ae1877e32ec9d4d01c3d0a
+    http-api-data-0.2.2-107631c0bae2e2a6211651e9a27c130c
+    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
+    monad-logger-0.3.17-d3b65fae3959e41c01434c1c220af3fd
+    path-pieces-0.2.1-c4c6ea4593a7da7123f92fac6c85ebd3
+    persistent-2.2.4-6358b6402a63bdc879cbf54a9eb5e6c6
+    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
-    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
+    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    unordered-containers-0.2.6.0-08e36bb27daebf8e082345cc5a0772e7
+    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
 haddock-interfaces: /usr/share/doc/haskell-persistent-template/html/persistent-template.haddock
 haddock-html: /usr/share/doc/haskell-persistent-template/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
